package com.pcloud.book.guide.listener;

import com.alibaba.fastjson.JSONObject;
import com.pcloud.book.guide.dto.PcloudGuideDelayMsgDto;
import com.pcloud.book.guide.vo.PcloudGuideMessageVO;
import com.pcloud.book.keywords.enums.ReplyTypeEnum;
import com.sdk.wxgroup.SendPicMessageVO;
import com.sdk.wxgroup.SendTextMessageVO;
import com.sdk.wxgroup.WxGroupSDK;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.annotation.RabbitHandler;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.messaging.handler.annotation.Payload;
import org.springframework.stereotype.Component;

import static com.pcloud.book.guide.constant.DelayQueueConstant.BOOK_DELAY_QUEUE;

/**
 * 平台端 个人号 引导语 延时消息监听
 */
@Slf4j
@Component
public class PcloudGuideListener {


    @RabbitListener(queues = BOOK_DELAY_QUEUE)
    @RabbitHandler
    public void activeRemind(@Payload String body) {
        PcloudGuideDelayMsgDto msgDto = JSONObject.parseObject(body, PcloudGuideDelayMsgDto.class);
        PcloudGuideMessageVO message = msgDto.getPcloudGuideMessageVO();
        Integer replyType = message.getReplyType();
        if (ReplyTypeEnum.TEXT.value.equals(replyType)){
            SendTextMessageVO sendTextMessageVO = new SendTextMessageVO();
            sendTextMessageVO.setContent(message.getContent());
            sendTextMessageVO.setAltId(msgDto.getRobotId());
            sendTextMessageVO.setWxGroupId(msgDto.getWxId());
            sendTextMessageVO.setIp(msgDto.getIp());
            sendTextMessageVO.setCode(msgDto.getCode());
            WxGroupSDK.sendTextMessage(sendTextMessageVO);
        }
        if (ReplyTypeEnum.IMAGE.value.equals(replyType)) {
            SendPicMessageVO sendPicMessageVO = new SendPicMessageVO();
            sendPicMessageVO.setPicUrl(message.getPicUrl());
            sendPicMessageVO.setAltId(msgDto.getRobotId());
            sendPicMessageVO.setWxGroupId(msgDto.getWxId());
            sendPicMessageVO.setIp(msgDto.getIp());
            sendPicMessageVO.setCode(msgDto.getCode());
            WxGroupSDK.sendPicMessage(sendPicMessageVO);
        }
    }


}
